/*
  GEMPage - menu page (or level) for GEM library. Consists of a list of menu items.

  GEM (a.k.a. Good Enough Menu) - Arduino library for creation of graphic multi-level menu with
  editable menu items, such as variables (supports int, byte, boolean, char[17] data types) and
  option selects. User-defined callback function can be specified to invoke when menu item is saved.
  
  Supports buttons that can invoke user-defined actions and create action-specific
  context, which can have its own enter (setup) and exit callbacks as well as loop function.

  Requires AltSerialGraphicLCD library by Jon Green (http://www.jasspa.com/serialGLCD.html).
  LCD screen must be equipped with SparkFun Graphic LCD Serial Backpack and properly set up
  to operate using firmware provided with aforementioned library.

  For documentation visit:
  https://github.com/Spirik/GEM

  Created by Alexander 'Spirik' Spiridonov, 8 Jan 2018
  
  This is free software. You can redistribute it and/or modify it under
  the terms of Creative Commons Attribution-ShareAlike 4.0 International License.
  To view a copy of this license, visit https://creativecommons.org/licenses/by-sa/4.0/
*/

#ifndef HEADER_GEMPAGE
#define HEADER_GEMPAGE

#include <Arduino.h>
#include "GEMItem.h"

// Forward declaration of GEM class
class GEM;

// Declaration of GEMPage class
class GEMPage {
  friend class GEM;
  public:
    /* 
      @param 'title_' - title of the menu page displayed at top of the screen
    */
    GEMPage(char* title_ = "");
    void addMenuItem(GEMItem& menuItem);              // Add menu item to menu page
    void setParentMenuPage(GEMPage& parentMenuPage);  // Specify parent level menu page (to know where to go back to when pressing Back button)
  private:
    char* title;
    byte currentItemNum = 0;                          // Currently selected (focused) menu item of the page
    byte itemsCount = 0;
    GEMItem* getMenuItem(byte index);
    GEMItem* getCurrentMenuItem();
    GEMItem* _menuItem;                                         // First menu item of the page (the following ones are linked from within one another)
    GEMItem _menuItemBack {"", static_cast<GEMPage*>(nullptr)}; // Local instance of Back button (created when parent level menu page is specified through
                                                                // setParentMenuPage(); always becomes the first menu item in a list)
};
  
#endif
